==> dh-unattended-0.1.79.tgz: package/src/api/businessDocuments/allocatingTasks.ts <==
//调拨任务单Api
import {ResponseData,PageList} from 'dh-unattended/src/interface/publice/httpBase'
import {QueryAllocatingTasksListData, QueryAllocatingTasksListParams, AddAllocatingTasks} from "dh-unattended/src/interface/views/businessDocuments/allocatingTasks"

/**
 * @class 调拨任务单api类
 */

export default class AllocatingTasksApi {
  constructor(tant:any) {
    this.tant = tant
  }
  private tant:any

  //调拨计划列表查询
  allocationTaskPage(params:QueryAllocatingTasksListParams): Promise<ResponseData<PageList<QueryAllocatingTasksListData>>> {
    return this.tant.$fetch({
      url: '/unattended/allocationTask/page',
      method: 'get',
      params
    })
  }

  //添加
  allocationTaskAdd(data:AddAllocatingTasks): Promise<ResponseData<boolean>> {
    return this.tant.$fetch({
      url: '/unattended/allocationTask/add',
      method: 'post',
      data
    })
  }

  //编辑
  allocationTaskEdit(data:AddAllocatingTasks): Promise<ResponseData<boolean>> {
    return this.tant.$fetch({
      url: '/unattended/allocationTask/edit',
      method: 'post',
      data
    })
  }

  //审核
  toExamine(data: {allocationTaskIds: Array<number>}): Promise<ResponseData<boolean>> {
    return this.tant.$fetch({
      url: '/unattended/allocationTask/toExamine',
      method: 'post',
      data
    })
  }

  //反审
  deAudit(data: {allocationTaskIds: Array<number>}): Promise<ResponseData<boolean>> {
    return this.tant.$fetch({
      url: '/unattended/allocationTask/deAudit',
      method: 'post',
      data
    })
  }

  //生成倒运单
  generate(data: {allocationTaskId: number}): Promise<ResponseData<boolean>> {
    return this.tant.$fetch({
      url: '/unattended/allocationTask/generate',
      method: 'post',
      data
    })
  }
      //导入
  orderImportTemplate(file: any): Promise<ResponseData<boolean>> {
    const formData: FormData = new FormData()
    formData.append('file', file.file)
    return this.tant.$fetch({
      url: '/unattended/allocationTask/import',
      method: 'post',
      data: formData
    })
  }
}

==> dh-unattended-0.1.85.tgz: package/src/api/businessDocuments/allocatingTasks.ts <==
//调拨任务单Api
import {ResponseData,PageList} from 'dh-unattended/src/interface/publice/httpBase'
import {QueryAllocatingTasksListData, QueryAllocatingTasksListParams, AddAllocatingTasks} from "dh-unattended/src/interface/views/businessDocuments/allocatingTasks"

/**
 * @class 调拨任务单api类
 */

export default class AllocatingTasksApi {
  constructor(tant:any) {
    this.tant = tant
  }
  private tant:any

  //调拨计划列表查询
  allocationTaskPage(params:QueryAllocatingTasksListParams): Promise<ResponseData<PageList<QueryAllocatingTasksListData>>> {
    return this.tant.$fetch({
      url: '/unattended/allocationTask/page',
      method: 'get',
      params
    })
  }

  //添加
  allocationTaskAdd(data:AddAllocatingTasks): Promise<ResponseData<boolean>> {
    return this.tant.$fetch({
      url: '/unattended/allocationTask/add',
      method: 'post',
      data
    })
  }

  //编辑
  allocationTaskEdit(data:AddAllocatingTasks): Promise<ResponseData<boolean>> {
    return this.tant.$fetch({
      url: '/unattended/allocationTask/edit',
      method: 'post',
      data
    })
  }

  //审核
  toExamine(data: {allocationTaskIds: Array<number>}): Promise<ResponseData<boolean>> {
    return this.tant.$fetch({
      url: '/unattended/allocationTask/toExamine',
      method: 'post',
      data
    })
  }

  //反审
  deAudit(data: {allocationTaskIds: Array<number>}): Promise<ResponseData<boolean>> {
    return this.tant.$fetch({
      url: '/unattended/allocationTask/deAudit',
      method: 'post',
      data
    })
  }

  //生成倒运单
  generate(data: {allocationTaskIds: Array<number>}): Promise<ResponseData<boolean>> {
    return this.tant.$fetch({
      url: '/unattended/allocationTask/generate',
      method: 'post',
      data
    })
  }
      //导入
  orderImportTemplate(file: any): Promise<ResponseData<boolean>> {
    const formData: FormData = new FormData()
    formData.append('file', file.file)
    return this.tant.$fetch({
      url: '/unattended/allocationTask/import',
      method: 'post',
      data: formData
    })
  }
}
